@@ -19,5 +19,4 @@ class OneTruePairingManager(models.Manager):
 
             kwargs["verification_code"] = verification_code
 
-        instance = super().create(*args, **kwargs)
-        return instance
+        return super().create(*args, **kwargs)
